@@ -183,6 +183,10 @@ class spartaquant():
         funcName = str(inspect.stack()[0][0].f_code.co_name)
         return self.sendRequests(funcName, thisDate, formatDate)
 
+    def putData(self, dataObj, name=None, apiId=None, dateDispo=None):
+        funcName = str(inspect.stack()[0][0].f_code.co_name)
+        return self.sendRequests(funcName, dataObj, name, apiId, dateDispo)
+
     def putExec(self, str2Eval, name):
         funcName = str(inspect.stack()[0][0].f_code.co_name)
         return self.sendRequests(funcName, str2Eval, name)
